@@ -28,11 +28,13 @@ void SetPositionOnLastIcon();
 
 void MakeWindowIcons();
 
-Window LowerIcons();
-
 void MakeWindowTree();
 
-void SortIcons(int type);
+Window LowerIcons();
+
+struct item *SortIcons(int type,struct item *top);
+
+void SortIconsTop(int type);
 
 void PlaceIcons();
 
@@ -48,5 +50,11 @@ void UnsetMarks();
 
 void SetAllMarks();
 
+void PlusTree(struct item *fileitem);
+
+void MinusTree(struct item *fileitem);
+
+void ArrangeTree();
+
 #endif
 
