@@ -4,26 +4,32 @@
 #ifndef TREE_H
 #define TREE_H
 
-#ifdef LOOK_WPS
+#ifdef LOOK_WPS_DONT_WORK_YET
 
 #include "wps/treeplus.xpm"
+#include "wps/treenoplus.xpm"
 #include "wps/treeminus.xpm"
 #include "wps/treelineH.xpm"
 #include "wps/treelineV.xpm"
+#include "wps/treeswitchb.xpm"
 
-#elif defined(LOOK_MAC)
+#elif defined(LOOK_MAC_DONT_WORK_YET)
 
 #include "mac/treeplus.xpm"
+#include "mac/treenoplus.xpm"
 #include "mac/treeminus.xpm"
 #include "mac/treelineH.xpm"
 #include "mac/treelineV.xpm"
+#include "mac/treeswitchb.xpm"
 
 #else
 
 #include "nice/treeplus.xpm"
+#include "nice/treenoplus.xpm"
 #include "nice/treeminus.xpm"
 #include "nice/treelineH.xpm"
 #include "nice/treelineV.xpm"
+#include "nice/treeswitchb.xpm"
 
 #endif
 
