@@ -30,6 +30,9 @@
 #include <zlib.h>
 #endif
 
+#include <libintl.h>
+#define _(string) gettext(string)
+
 Window deskwin=0;
 
 int IsDesktopActive()  
@@ -1026,11 +1029,11 @@ void SaveFileInfoFromDesktop()
 	      
 	      free(text);
 	      /*tttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttt*/	      
-	      direntry=direntry->NextItem;
+	      direntry=direntry->nextitem;
 	    }
 	    
 	    while(dirsave!=NULL) {
-	      direntry=dirsave->NextItem;
+	      direntry=dirsave->nextitem;
 	      free(dirsave->filename);
 	      free(dirsave);
 	      dirsave=direntry;
@@ -1463,7 +1466,7 @@ void GoalWasFolder(Window Quellwindow,char *foldername,
       status=CopyCall(0,0,filenames,foldername,True);
       if (status==NO_ERROR) {
 	if (EraseCall(filenames,False,True)!=NO_ERROR)
-	  Message("Can't delete Orginals!!!");
+	  Message(_("Can't delete Orginals!!!"));
       } else if (status==ASK_FOR_DELETE_ERROR) {
 	EraseCall(filenames,True,True);
       }
@@ -1472,11 +1475,11 @@ void GoalWasFolder(Window Quellwindow,char *foldername,
     } else {
       status=CopyCall(0,0,filenames,foldername,False);      
       if (status==ASK_FOR_DELETE_ERROR)
-	Message("Some ERROR occured!!!");
+	Message(_("Some ERROR occured!!!"));
     }
   }
   if (status==REPORT_ERROR)
-    Message("Some ERROR occured!!!");
+    Message(_("Some ERROR occured!!!"));
   UpdateIcons(True);
   SetPositionOnLastIcon(); 
   SendUpdate(foldername);
@@ -1522,7 +1525,7 @@ void SelectionReq(XEvent evnt)
 	                evnt.xselectionrequest.requestor,
                         evnt.xselectionrequest.property,
 			evnt.xselectionrequest.target,8,PropModeReplace,
-		        (unsigned char*)GetPrimary(),strlen(GetPrimary())+1);
+		        (unsigned char*)GetPrimary(),strlen(GetPrimary()));
         ev.type=SelectionNotify;
         ev.xselection.requestor=evnt.xselectionrequest.requestor;
         ev.xselection.selection=evnt.xselectionrequest.selection;
@@ -1591,7 +1594,7 @@ void WorkIncomingCall(XEvent evnt)
 			    y-(int)evnt.xclient.data.s[2],files,"",True);
 	    if (status==NO_ERROR) {
 	      if (EraseCall(files,False,True)!=NO_ERROR)
-	        Message("Can't delete Orginals!!!");
+	        Message(_("Can't delete Orginals!!!"));
 	    } else if (status==ASK_FOR_DELETE_ERROR) {
 	      UpdateIcons(True);
 	      EraseCall(files,True,True);
@@ -1602,11 +1605,11 @@ void WorkIncomingCall(XEvent evnt)
 	    status=CopyCall(x-(int)evnt.xclient.data.s[1],
 			    y-(int)evnt.xclient.data.s[2],files,"",False);
 	    if (status==ASK_FOR_DELETE_ERROR)
-	      Message("Some ERROR occured!!!");
+	      Message(_("Some ERROR occured!!!"));
 	  }
 	}
         if (status==REPORT_ERROR)
-    	  Message("Some ERROR occured!!!");
+    	  Message(_("Some ERROR occured!!!"));
 	UpdateIcons(True);
         SetPositionOnLastIcon();
       }
