@@ -946,14 +946,14 @@ void FileApplyCallback(GtkWidget *widget, gpointer data)
   strcat(text,gtk_entry_get_text(GTK_ENTRY(objax)));
   strcat(text," ");
   strcat(text,textn);
-  usershellsystem(text);
+  usershellsystem(text,NULL);
   free(text);
   text=malloc(strlen("chgrp  ")+strlen(textn)+strlen(gtk_entry_get_text(GTK_ENTRY(objbx)))+1);
   strcpy(text,"chgrp ");
   strcat(text,gtk_entry_get_text(GTK_ENTRY(objbx)));
   strcat(text," ");
   strcat(text,textn);
-  usershellsystem(text);
+  usershellsystem(text,NULL);
   free(text);
   text3=malloc(strlen(name)+1);
   strcpy(text3,name);
@@ -996,7 +996,7 @@ void FileApplyCallback(GtkWidget *widget, gpointer data)
 	text[8]=text[8]+2;
       if (GTK_TOGGLE_BUTTON(objwx)->active)
 	text[8]++;
-      usershellsystem(text);
+      usershellsystem(text,NULL);
       free(text);
     }
     sprintf(linktext,"%ld",info.st_size);
@@ -1449,14 +1449,14 @@ void MultipleFileApplyCallback(GtkWidget *widget, gpointer data)
       strcat(text,gtk_entry_get_text(GTK_ENTRY(objax)));
       strcat(text," ");
       strcat(text,textn);
-      usershellsystem(text);
+      usershellsystem(text,NULL);
       free(text);
       text=malloc(strlen("chgrp  ")+strlen(textn)+strlen(gtk_entry_get_text(GTK_ENTRY(objbx)))+1);
       strcpy(text,"chgrp ");
       strcat(text,gtk_entry_get_text(GTK_ENTRY(objbx)));
       strcat(text," ");
       strcat(text,textn);
-      usershellsystem(text);
+      usershellsystem(text,NULL);
       free(text);
     }
 
@@ -1482,7 +1482,7 @@ void MultipleFileApplyCallback(GtkWidget *widget, gpointer data)
 	text[8]=text[8]+2;
       if (GTK_TOGGLE_BUTTON(objwx)->active)
 	text[8]++;
-      usershellsystem(text);
+      usershellsystem(text,NULL);
       free(text);
     }
     free(textn);
