@@ -16,7 +16,7 @@ char* CutHomeDir(char* file);
 
 char* ExpandTilde(char* part);
 
-int usershellsystem(char* command);
+int usershellsystem(char* command,char *path);
 
 void ExecuteShellWithFollowLink(char *filename,char *start,char *files,int shnr);
 
